@@ -21,3 +21,10 @@ impl Default for Config {
         }
     }
 }
+
+/// Configures Python documentation generation.
+#[derive(Clone, Debug, Default)]
+pub struct DocConfig {
+    /// Header to append to the generated documentation.
+    pub header: String,
+}
